### Loading the necessary packages ###
library(raster)
### Setting the working directory ####
### We produce the example for the average estimates ###
setwd("[input your working directory here]")

#### Loading the biophysical estimates of reforestation climate mitigation potential ###
biophy <- raster("Biophysical_Climate mitigation potential.tif")

#### Loading the financial constraints ###
financial <- raster("Financial_Constraints.tif")
## 3 --> High estimate: direct and opportunity costs from foregone agricultural rent 
## 2 --> Moderate estimate: direct and opportunity costs from foregone agricultural rent, weighted by the likelihood of agricultural development
## 1 --> Low estimate: only direct costs are considered (e.g. site selection, planting and maintenance) 

#### Loading the land-use constraints ###
Landuse <- raster("Landuse_Constraints.tif")
## 2 --> Less permissive: All smallholder agriculture land excluded 
## 1 --> More permissive: Only low yielding smallholder agriculture land is excluded 

#### Loading the operational constraints ###
operational <- list.files(pattern="Operational")
i=1
operational1 <- raster(operational[i])
for(i in 2:4){
	operational1 <- stack(operational1,raster(operational[i]))
}
## Operational constraint for SS, PA, DR and AM. 
 

############## Independent Constraints Scenario ##############
### Estimates climate mitigation potential under financial constraints ###
### 3 levels of financial constraints ###
FC <- data.frame(FinancialConstraint=c("Low estimate","Moderate estimate","High estimate"),CMP=c(NA,NA,NA))
for(i in 1:3){
	preproc <- calc(financial,function(x){x[x!=i] <- NA;return(x)})
	preproc1 <- calc(preproc,function(x){x[!is.na(x)] <- 0;return(x)})
	FinEstimate <- calc(stack(biophy, preproc1),sum)
	FC[i,2] <- cellStats(FinEstimate,sum)/1000000000*100 ### converted in to PgCO2e/yr, adjusting hectares to km2
}
FC$CMP <- FC$CMP
FC$CMP[2] <- FC$CMP[2]+FC$CMP[3]
FC$CMP[1] <- FC$CMP[1]+FC$CMP[2]

### Estimates climate mitigation potential under landuse constraints ###
### 2 levels of landuse constraints ###
LC <- data.frame(LanduseConstraint=c("More permissive","Less permissive"),CMP=c(NA,NA))
for(i in 1:2){
	preproc <- calc(Landuse,function(x){x[x!=i] <- NA;return(x)})
	preproc1 <- calc(preproc,function(x){x[!is.na(x)] <- 0;return(x)})
	LandEstimate <- calc(stack(biophy, preproc1),sum)
	LC[i,2] <- cellStats(LandEstimate,sum)/1000000000*100 ### converted in to PgCO2e/yr, adjusting hectares to km2
}
LC $CMP[1] <- LC $CMP[1]+ LC $CMP[2]

### Estimates climate mitigation potential under operational constraints ###
### 4 levels of operational constraints ###
OC <- data.frame(OperationalConstraint=paste0(gsub("Operational_Constraints_","",gsub(".tif","", operational))),CMP=NA)
plot(operational1[[1]])
for(i in 1:4){
	OperEstimate <- calc(stack(biophy, operational1[[i]]),sum)
	OC[i,2] <- cellStats(OperEstimate,sum)/1000000000 * 100 ### converted in to PgCO2e/yr, adjusting hectares to km2
	}


############## Contingent constraints scenario ##############
### This is the example for the full contingent constraint scenario: High cost estimate + Less permissive landuse + All operational constraints ###
### See Methods for description of other additional constraint scenarios ###

### High cost estimate ###
financial1 <- calc(financial,function(x){x[x!=3] <- NA;return(x)})
financial1 <- calc(financial1,function(x){x[!is.na(x)] <- 0;return(x)})

FinEstimate <- calc(stack(biophy, financial1),sum)

cellStats(FinEstimate,sum)/1000000000*100 ### converted in to PgCO2e/yr, adjusting hectares to km2

### Less permissive landuse ###
Landuse1 <- calc(Landuse,function(x){x[x!=2] <- NA;return(x)})
Landuse1 <- calc(Landuse1,function(x){x[!is.na(x)] <- 0;return(x)})

LandEstimate <- calc(stack(FinEstimate, Landuse1),sum)

cellStats(LandEstimate,sum)/1000000000*100 ### converted in to PgCO2e/yr, adjusting hectares to km2

### Less permissive landuse ###
Landuse1 <- calc(Landuse,function(x){x[x!=2] <- NA;return(x)})
Landuse1 <- calc(Landuse1,function(x){x[!is.na(x)] <- 0;return(x)})

LandEstimate <- calc(stack(FinEstimate, Landuse1),sum)

cellStats(LandEstimate,sum)/1000000000*100 ### converted in to PgCO2e/yr, adjusting hectares to km2

### All operational constraints ###
OC <- data.frame(OperationalConstraint=paste0(gsub("Operational_Constraints_","",gsub(".tif","", operational))),CMP=NA)
for(i in 1:4){
	OperEstimate <- calc(stack(LandEstimate, operational1[[i]]),sum)
	OC[i,2] <- cellStats(OperEstimate,sum)/1000000000 * 100 ### converted in to PgCO2e/yr, adjusting hectares to km2
	}
OC
